@@ -1,6 +1,6 @@
 package MasonCallbackTester;
 
-# $Id: MasonCallbackTester.pm,v 1.15 2003/06/29 20:20:59 david Exp $
+# $Id: MasonCallbackTester.pm,v 1.16 2003/07/02 01:42:23 david Exp $
 
 use strict;
 use MasonX::ApacheHandler::WithCallbacks;
@@ -169,6 +169,18 @@ my %tests = ( '/bad_key' => sub {
                   my $ahwc = MasonX::ApacheHandler::WithCallbacks->new( %params );
                   $ahwc->handle_request(@_);
               },
+
+              '/no_null' => sub {
+                  my %c = (%cb_config,
+                           cb_key  => 'simple',
+                           cb      => \&simple);
+                  my $ahwc = MasonX::ApacheHandler::WithCallbacks->new
+                      ( %params,
+                        exec_null_cb_values => 0,
+                        callbacks => [\%c] );
+                  $ahwc->handle_request(@_);
+              },
+
             );
 
 
